@@ -30,6 +30,7 @@
 #include <QSharedMemory>
 #include <QSystemSemaphore>
 #include <QDBusConnection>
+#include <QThreadStorage>
 
 #include "../shared/udevqt.h"
 
@@ -216,6 +217,8 @@ private:
         {
             m_mem->unlock();
         }
+        Unlocker(const Unlocker &) = delete;
+        Unlocker &operator=(const Unlocker &) = delete;
     private:
         QSharedMemory *m_mem;
     };
@@ -227,6 +230,8 @@ private:
         {
             m_sem->release();
         }
+        Releaser(const Releaser &) = delete;
+        Releaser &operator=(const Releaser &) = delete;
     private:
         QSystemSemaphore *m_sem;
     };
@@ -301,7 +306,7 @@ public:
     }
 };
 
-Q_GLOBAL_STATIC(SharedContentTypesCache, sharedContentTypesCache)
+Q_GLOBAL_STATIC(QThreadStorage<SharedContentTypesCache>, sharedContentTypesCache)
 
 OpticalDisc::Identity::Identity() : m_detectTime(0), m_size(0), m_labelHash(0)
 {
@@ -415,7 +420,7 @@ Solid::OpticalDisc::ContentTypes OpticalDisc::availableContent() const
         if (!(m_identity == newIdentity)) {
             QByteArray deviceFile(m_device->prop("Device").toByteArray());
             m_cachedContent =
-                sharedContentTypesCache->getContent(newIdentity, deviceFile);
+                sharedContentTypesCache->localData().getContent(newIdentity, deviceFile);
             m_identity = newIdentity;
         }
 
